<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: ForecastingChannelChannelStatistic.mcf.broken.test.php 5631 2006-10-09 18:21:43Z andrew@m3.net $
*/


require_once MAX_PATH . '/lib/Max.php';
require_once MAX_PATH . '/lib/max/core/ServiceLocator.php';
require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Table/Core.php';
require_once MAX_PATH . '/lib/max/Maintenance.php';
require_once 'Date.php';

require_once MAX_PATH . '/lib/max/Maintenance/Forecasting/Channel/ChannelStatistic.php';

/**
 * A class for testing the ChannelLimitations class.
 *
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     Radek Maciaszek <radek@m3.net>
 */
class Maintenance_TestOfChannelStatistic extends UnitTestCase
{
    var $errorLevel;
    
    function setUp()
    {
        $this->errorLevel = error_reporting(E_ALL);
    }
    
    function tearDown()
    {
        error_reporting($this->errorLevel);
    }
    
    /**
     * The constructor method.
     */    
    function Maintenance_TestOfChannelStatistic()
    {        
        $this->UnitTestCase();
        
        $oServiceLocator = &ServiceLocator::instance();
        
        Mock::generate('MAX_Maintenance_Forecasting_Channel_ChannelLimitations');
        $oChannelLimitations = &new MockMAX_Maintenance_Forecasting_Channel_ChannelLimitations($this);
        $oServiceLocator->register('MAX_Maintenance_Forecasting_Channel_ChannelLimitations', $oChannelLimitations);
        
        Mock::generate('MAX_Dal_Forecasting');
        $oDal = &new MockMAX_Dal_Forecasting($this);
        $oServiceLocator->register('MAX_Dal_Forecasting', $oDal);
    }
    
    /**
     * Test summarize
     */
    function testSummarizeZonesBySqlLimitations()
    {
        $oServiceLocator = &ServiceLocator::instance();
        
        $chStat = new MAX_Maintenance_Forecasting_Channel_ChannelStatistic();
        $chStat->oDal = $oServiceLocator->get('MAX_Dal_Forecasting');
        $chStat->oChannelLimitations = $oServiceLocator->get('MAX_Maintenance_Forecasting_Channel_ChannelLimitations');
        
        $chStat->_channelTables = array('boo', 'foo');
        $amountOfChannelsTypes = count($chStat->_channelTables);
        
        $chStat->oChannelLimitations->expectOnce('getSqlLimitations');
        $chStat->oDal->expectCallCount('countNumberOfRecordsInZonesBySqlLimitations', $amountOfChannelsTypes);
        $chStat->oDal->expectCallCount('saveChannelSummaryForZones', $amountOfChannelsTypes);
        
        $chStat->summarizeZonesBySqlLimitations(array(1), 2);
        
        $chStat->oChannelLimitations->tally();
        $chStat->oDal->tally();
    }
    
    /**
     * Test summarize
     */
    function testSummarizeZonesBySqlAndPhpLimitations()
    {
        $oServiceLocator = &ServiceLocator::instance();
        
        $chStat = new MAX_Maintenance_Forecasting_Channel_ChannelStatistic();
        $chStat->oDal = $oServiceLocator->get('MAX_Dal_Forecasting');
        $chStat->oChannelLimitations = $oServiceLocator->get('MAX_Maintenance_Forecasting_Channel_ChannelLimitations');
        
        $chStat->_channelTables = array('boo', 'foo');
        $amountOfChannelsTypes = count($chStat->_channelTables);
        
        $chStat->oChannelLimitations->expectOnce('getSqlLimitations');
        $chStat->oChannelLimitations->expectOnce('getPhpLimitations');
        $chStat->oDal->expectCallCount('countNumberOfRecordsInZonesBySqlAndPhpLimitations', $amountOfChannelsTypes);
        $chStat->oDal->expectCallCount('saveChannelSummaryForZones', $amountOfChannelsTypes);
        
        $chStat->summarizeZonesBySqlAndPhpLimitations(array(1), 2);
        
        $chStat->oChannelLimitations->tally();
        $chStat->oDal->tally();
    }
    
    /**
     * Test summarize
     */
    function testSummarizeRawDataForChannel()
    {
        $oServiceLocator = &ServiceLocator::instance();
        
        Mock::generatePartial(
            'MAX_Maintenance_Forecasting_Channel_ChannelStatistic',
            'PartialChannelStatistic',
            array('summarizeZonesBySqlLimitations', 'summarizeZonesBySqlAndPhpLimitations'));
        
        // Test 1: if php limitations are empty
        $chStat = new PartialChannelStatistic($this);
        
        $chStat->oChannelLimitations = $oServiceLocator->get('MAX_Maintenance_Forecasting_Channel_ChannelLimitations');
        
        $zoneIds = array(1,2,3);
        
        $chStat->oChannelLimitations->expectOnce('buildLimitations');
        $chStat->expectCallCount('summarizeZonesBySqlLimitations', 1);
        
        $chStat->summarizeRawDataForChannel(1, $zoneIds);
        $chStat->oChannelLimitations->tally();
        $chStat->tally();
        
        // Test 2: if php limitations are not empty
        $chStat = new PartialChannelStatistic($this);
        
        $chStat->oChannelLimitations = $oServiceLocator->get('MAX_Maintenance_Forecasting_Channel_ChannelLimitations');
        
        $zoneIds = array(1,2,3);
        
        $chStat->oChannelLimitations->phpLimitations = 'non empty';
        $chStat->oChannelLimitations->expectOnce('buildLimitations');
        $chStat->expectCallCount('summarizeZonesBySqlAndPhpLimitations', 1);
        
        $chStat->summarizeRawDataForChannel(1, $zoneIds);
        $chStat->oChannelLimitations->tally();
        $chStat->tally();
    }
    
    /**
     * Test summarizing raw data
     */
    function testSummarizeRawData()
    {
        $oServiceLocator = &ServiceLocator::instance();
        
        Mock::generatePartial(
            'MAX_Maintenance_Forecasting_Channel_ChannelStatistic',
            'PartialChannelStatisticForSummarizeRawData',
            array('summarizeRawDataForChannel'));
        
        $chStat = new PartialChannelStatisticForSummarizeRawData($this);
        
        $chStat->oDal = $oServiceLocator->get('MAX_Dal_Forecasting');
        
        $agenciesIds = array(1,2,3);
        $channelIds = array(1,2,3);
        $publisherIds = array(1,2,3);
        $tmpChannelIds = array(3,4);
        $zoneIds = array(1,2,3,4);
        $channelIds = array_merge($channelIds, $tmpChannelIds);
        
        $chStat->oDal->expectOnce('getAgenciesIds');
        $chStat->oDal->setReturnValue('getAgenciesIds', $agenciesIds);
        
        $chStat->oDal->expectCallCount('getChannelsByAgencyId', count($agenciesIds));
        $chStat->oDal->setReturnValue('getChannelsByAgencyId', $channelIds);
        $chStat->oDal->expectCallCount('getPublishersIds', count($agenciesIds));
        $chStat->oDal->setReturnValue('getPublishersIds', $publisherIds);
        
        $chStat->oDal->expectCallCount('getChannelsIdsByAgencyPublisher', count($agenciesIds)*count($publisherIds));
        $chStat->oDal->setReturnValue('getChannelsIdsByAgencyPublisher', $tmpChannelIds);
        
        $chStat->oDal->expectCallCount('getZonesIds', count($agenciesIds)*count($publisherIds));
        $chStat->oDal->setReturnValue('getZonesIds', $zoneIds);
        
        $chStat->expectCallCount('summarizeRawDataForChannel', count($agenciesIds)*count($publisherIds)*count($channelIds));
        
        $chStat->summarizeRawData();
        
        $chStat->oDal->tally();
        $chStat->tally();
    }
    
    /**
     * Test summarizing run()
     */
    function testRun()
    {
        $oServiceLocator = &ServiceLocator::instance();
        
        Mock::generatePartial(
            'MAX_Maintenance_Forecasting_Channel_ChannelStatistic',
            'PartialChannelStatisticSummarizeRawData',
            array('summarizeRawData', '_init'));
        
        $chStat = new PartialChannelStatisticSummarizeRawData($this);
        
        $oServiceLocator = &ServiceLocator::instance();
        $chStat->oDal = $oServiceLocator->get('MAX_Dal_Forecasting');
        $chStat->oDal->setReturnValue('setIntervalDates', true);
        
        $amountOfHours = 5;
        
        $chStat->conf['maintenance']['operationInterval'] = 60; // in minutes
        $chStat->conf['maintenance']['channelForecastingMaxRunTime'] = 40; // in minutes
        
        $chStat->lastDateOI = new Date('2005-08-02 09:59:59');
        $chStat->lastDateOI->subtractSeconds(3600 * $amountOfHours);
        $chStat->upToDateOI = new Date('2005-08-02 09:59:59');
        
        $chStat->expectCallCount('summarizeRawData', $amountOfHours);
        
        $chStat->run();
        
        $chStat->tally();
    }
    
}

?>
